From c89c769f4e76b93b42001f1921841cc3e5730aff Mon Sep 17 00:00:00 2001
From: Tomas Janousek <tomi@nomi.cz>
Date: Fri, 13 Apr 2007 00:50:49 +0200
Subject: [PATCH] Fix a focus issue with workspace changing.
When a focused window gets unmapped before unfocused ones, the focus slips
to the window under the cursor. If the mouse is not there when the window
is mapped again, the window never receives FocusOut, resulting in two
windows looking like having focus.
---
 src/Workspace.cc |   15 +++++++++++++--
 1 files changed, 13 insertions(+), 2 deletions(-)

diff --git a/src/Workspace.cc b/src/Workspace.cc
index 05d8420..8c5811c 100644
--- a/src/Workspace.cc
+++ b/src/Workspace.cc
@@ -147,10 +147,21 @@ void Workspace::showAll() {
 void Workspace::hideAll(bool interrupt_moving) {
     Windows::reverse_iterator it = m_windowlist.rbegin();
     Windows::reverse_iterator it_end = m_windowlist.rend();
+    Windows::reverse_iterator focused = it_end;
     for (; it != it_end; ++it) {
-        if (! (*it)->isStuck())
-            (*it)->withdraw(interrupt_moving);
+        if (! (*it)->isStuck()) {
+            if ((*it)->isFocused())
+                focused = it;
+            else
+                (*it)->withdraw(interrupt_moving);
+        }
     }
+
+    /* We have to unmap the focused window last, because otherwise the focus
+     * may slip to the window under the cursor and this window may not be
+     * unfocused in some occasions. */
+    if (focused != it_end)
+        (*focused)->withdraw(interrupt_moving);
 }
 
 
-- 
1.5.1

